$color-tertiary: #ff5733;

.site-blocks-cover {
	background-size: cover;
	background-repeat: no-repeat;
	background-position: top;
	&.overlay {
		position: relative;
		&:before {
			position: absolute;
			content: "";
			left: 0;
			bottom: 0;
			right: 0;
			top: 0;
			background: rgba($black, .4);
		}
	}
	&, .row {
		min-height: 600px;
		height: calc(100vh);
	}
	&.inner-page {
		&, .row {
			min-height: 600px;
			height: calc(80vh);	
		}
	}
	.sub-text {
		font-size: $font-size-base + .1rem;	
		text-transform: uppercase;
		color: rgba($white, .7);
		letter-spacing: .2em;
	}
	h1 {
		font-weight: 900;
		color: $white;
		// text-transform: uppercase;
		font-size: $font-size-base + 2rem;	
		strong {
			font-weight: 900;
		}
		@include media-breakpoint-up(md) {
			font-size: $font-size-base + 4rem;	
			// font-weight: 300;
			// line-height: 1.2;
		}
	}
	p {
		color: $white;
		font-size: $font-size-base + .5rem;
		line-height: 1.5;
	}
	.intro-text {
		font-size: 16px;
		line-height: 1.5;
	}
}

.site-heading {
	
	font-weight: 300;
	text-transform: uppercase;
	font-size: $font-size-base + 1rem;
	@include media-breakpoint-up(md) {
		font-size: $font-size-base + 2rem;	
	}
	strong {
		font-weight: 900;
	}
}

.site-block-1 {
	padding-top: 50px;
	@include media-breakpoint-up(lg) {
		padding-top: 0;
		position: absolute;
		width: 100%;
		transform: translateY(-100%);
	}
}

.site-block-appointment, .bg-light {
	// background: #ece8d9!important;
	form {
		box-shadow: 0 5px 20px -2px rgba(0,0,0,.1);
	}
}
.text-white-opacity-5 {
	color: rgba($white, .5);
}
.text-black-opacity-5 {
	color: rgba($black, .5);
}

.site-block-feature {
	background: rgba($black, .5);
	position: relative;
	transition: .3s all ease;
	top: 0;
	.icon {
		font-size: 50px;
		transition: .3s all ease;
		color: $white;
	}
	h3 {
		transition: .3s all ease;
		font-size: 15px;
		color: $primary;
	}
	p {
		transition: .3s all ease;
		color: rgba($white, .4);
		font-size: $font-size-base;
		&:last-child {
			margin-bottom: 0;
		}
	}
	&:hover {
		background: $white;
		top: -5px;
		.icon {
			color: $primary;
		}
		h3 {
			color: $black;
		}
		p {
			color: lighten($black, 50%);
		}
	}
}
.site-block-feature-2 {
	.icon {
		font-size: 50px;
		position: relative;
		line-height: 1;
	}
	h3 {
		font-size: $font-size-base + .5rem;
	}
}

.site-block-3 {
	.row-items {
		height: calc(50% - 15px);
		margin-bottom: 30px;
		&.last {
			height: calc(50% - 15px);
			margin-bottom: 0;
		}
	}
	.feature {
		transition: .3s all ease-in-out;
		height: 100%;
		top: 0px;
		position: relative;
		h3 {
			color: $black;
			font-size: $font-size-base + .2rem;
		}
		&:hover, &:active, &:focus, &.active {
			box-shadow: 0 5px 20px -5px rgba(0,0,0,.1);
		}
		&:hover {
			top: -10px;
		}
	}
}

.site-block-half {
	.image, .text {
		width: 100%;
		@include media-breakpoint-up(lg) {
			width: 50%;	
		}
	}
	.image {
		@include media-breakpoint-down(md) {
			margin-bottom: 50px;
		}
	}
	.text {
		padding-left: 15px;
		padding-right: 15px;
		@include media-breakpoint-up(lg) {
			padding: 4rem;	
		}
		@include media-breakpoint-up(xl) {
			padding: 8rem;	
		}
	}
	.bg-image {
		background-position: center center;
		@include media-breakpoint-down(md) {
			height: 400px;
		}
	}

	&.site-block-video {
		.image {
			position: relative;
			.play-button {
				position: absolute;
				top: 50%;
				left: 50%;
				transform: translate(-50%, -50%);
				font-size: 20px;
				width: 70px;
				height: 70px;
				background: $white;
				display: block;
				border-radius: 50%;
				opacity: 1;
				color: $primary!important;
				&:hover {
					opacity: 1;
				}
				> span {
					position: absolute;
					left: 55%;
					top: 50%;
					transform: translate(-60%, -50%);
				}

			}
		}
	}
}



#date-countdown {
	.countdown-block {
		color: rgba($white, .4);
	}
	.label {
		font-size: 40px;
		color: $white;
	}
}

.next-match {
	.image {
		width: 50px;
		border-radius: 50%;
	}
}

.player {
	position: relative;
	img {
		max-width: 100px;
		border-radius: 50%;
		margin-bottom: 20px;
	}
	.team-number {
		position: absolute;
		width: 30px;
		height: 30px;
		background: $primary;
		border-radius: 50%;
		color: $white;
		> span {
			position: absolute;
			transform: translate(-50%, -50%);
			left: 50%;
			top: 50%;
		}
	}
	h2 {
		font-size: 20px;
		letter-spacing: .2em;
		text-transform: uppercase;
	}
	.position {
		font-size: 14px;
		color: lighten($black, 70%);
		text-transform: uppercase;
	}
}

.site-block-27 {
	ul {
		&, li {
			padding: 0;
			margin: 0;
		}
		li {
			display: inline-block;
			margin-bottom: 4px;
			a,span {
				text-align: center;
				display: inline-block;
				width: 40px;
				height: 40px;
				line-height: 40px;
				border-radius: 50%;
				border: 1px solid #ccc;
			}
			&.active {
				a, span {
					background: $primary;
					color: $white;
					border: 1px solid transparent;
				}
			}
		}
	}
}

.img-border {
	position: relative;
	&:before {
		position: absolute;
		content: "";
		top: 20px;
		left: 20px;
		right: 20px;
		bottom: 20px;
		border: 7px solid $primary;
	}
}

.sub-title {
	display: block;
	text-transform: uppercase;
	letter-spacing: .1em;
	font-size: 12px;
	font-weight: 700;
	color: $color-tertiary;
	margin-bottom: 10px;
}
.about-section {
	// position: relative;
	
	.img-years {
		position: relative;
		.experience {
			position: absolute;
			display: block;
			right: 0;
		}
		.caption {
			display: block;
			text-transform: uppercase;
			letter-spacing: .8em;
			font-size: 14px;
			font-weight: 900;
			color: $color-tertiary;
			@include media-breakpoint-down(md) {
				letter-spacing: .3em;
			}
		}
		.years {
			line-height: 1.2;
			font-weight: 900;
			font-size: 100px;
			color: $color-tertiary;
			@include media-breakpoint-down(md) {
				font-size: 80px;
			}
		}
	}
	h3 {
		font-size: 30px;
		font-weight: bold;
		color: $black;
	}
	p {

	}
}

.media {
	&.custom-media {
		.icon {
			position: relative;
			color: $black;
			&:before {
				content: "";
				position: absolute;
				width: 60px;
				height: 60px;
				border-radius: 50%;
				background-color: $color-tertiary;
				left: -15px;
				top: -5px;
				z-index: -1;
			}
		}
	}
}

.site-half {
	position: relative;
	.img-bg-1 {
		background-size: cover;
		background-position: center center;
		background-repeat: no-repeat;
		position: absolute;
		width: 50%;
		height: 100%;
		left: -10%;
		@include media-breakpoint-down(md) {
			position: relative;
			height: 500px;
			left: 0;
			width: 100%;
		}
		&.right {
			right: 0;
		}
	}
}

.ul-check {
	li {
		position: relative;
		padding-left: 30px;
		margin-bottom: 10px;
		&:before {
			font-family: "icomoon";
			content: "\e5ca";
			position: absolute;
			left: 0;
			top: .6em;
			font-size: 20px;
			line-height: 0;
		}
	}
	&.primary {
		li:before {
			color: $primary;
		}
	}
	&.success {
		li:before {
			color: $success;
		}
	}
	&.danger {
		li:before {
			color: $danger;
		}
	}
}

.accordion {

	button {
		color: $primary;
		&.collapsed {
			color: $black;
		}
	}
}

.block-13, .block-14, .block-15, .slide-one-item {
	position: relative;
	z-index: 1; 
	.owl-nav {
		position: relative;
		position: absolute;
		bottom: 0px;
		left: 50%;
		transform: translateX(-50%);
		.owl-prev, .owl-next {
			position: relative;
			display: inline-block;
			// padding: 10px;
			width: 50px;
			height: 50px;
			line-height: 54px;
			text-align: center;
			font-size: 25px;
			color: $black;
			&.disabled {
				opacity: .2;
			}
		}
	}
	&.nav-direction-white {
		.owl-prev, .owl-next {
			background: $white;
			padding: 5px 10px;
			transition: .3s all ease;
			&:hover {
				box-shadow: 5px 5px 30px -5px rgba(0,0,0,.1);
			}
		}
	}
} 

.block-13, .block-14, .block-15 {
	.owl-stage-outer {
		padding-top: 30px;
		padding-bottom: 30px;
	}
	.owl-nav {
		position: absolute;
		width: 100%;
		top: 50%;
		left: 0;
		transform: translateY(-50%);
		@include media-breakpoint-down(md) {
			display: none;
		}
		.owl-prev, .owl-next {
			position: absolute;
			top: 50%;
			transform: translateY(-50%);
			box-shadow: 0 0 30px -5px rgba(0,0,0,.2);
			background: $white;
		}
		.owl-prev {

			left: -20px;
		}
		.owl-next {
			right: -20px;

		}
	}
	.owl-dots {
		text-align: center;
		// border: 1px solid red;
		.owl-dot {
			display: inline-block;
			margin: 5px;
			> span {
				line-height: 0;
				display: inline-block;
				width: 7px;
				height: 7px;
				border-radius: 50%;
				border: none;
				float: left;
				background: lighten($black, 80%);
				transition: .3s all ease;
			}
			&.active {
				> span {
					background: $primary;
				}
			}
		}
	}
}

.person {
	position: relative;
	figure {
		position: relative;
		margin-bottom: 0;
		&:before {
			position: absolute;
			content: "";
			z-index: 1;
			left: 10px;
			top: 10px;
			right: 10px;
			bottom: 10px;
			border: 5px solid $primary;
			opacity: 1;
			visibility: visible;
			transition: .3s all ease;
		}
	}
	h2 {
		font-size: 18px;
	}
	.bio-img {
		position: relative;
		text-align: center;
		overflow: hidden;
		margin-bottom: 30px;
		.social {
			z-index: 2;
			padding: 10px 0;
			width: 100%;
			position: absolute;
			bottom: 0%;
			transform: translateY(100%);
			left: 0;
			transition: .3s all ease;
			background: rgba($black, .25);
			a {
				display: inline-block;
				padding: 5px;
			}
		}
	}
	&:hover {
		.social {
			bottom: 0;
			transform: translateY(0%);
		}
		figure {
			&:before {
				opacity: 0;
				visibility: hidden;
			}
		}
	}
}

.post-entry, .project-entry {
	overflow: hidden;
	position: relative;
	display: block;
	.figure {
		overflow: hidden;
		margin-bottom: 20px;
	}
	h3 {
		font-size: 18px;
		line-height: 1.3;
		a {
			color: $black;
		}
	}
	img {
		transition: .3s all ease;
		transform: scale(1.0);
	}
	&:hover {
		img {
			transform: scale(1.05);
		}
	}
}

.testimony {
	text-align: center;
	z-index: 1;
	position: relative;
	padding: 30px;
	img {
		max-width: 100px;
		border-radius: 50%;
		margin: 0 auto 30px auto;
	}
	.sub-title {
		margin-bottom: 30px;
	}
	h3 {
		font-size: 18px;
	}
}


.site-block-testimony {
	img {
		max-width: 140px;
		border-radius: 50%;
	}
	p {
		font-size: $font-size-base + .2rem;
	}
	&.active {
		background: $white;
		box-shadow: 0 5px 20px -2px rgba(0,0,0,.1);
	}
}



.block-12 {
	position: relative;
	figure {
		position: relative;
		&:before {
			content: '';
	    position: absolute;
	    top: 0;
	    right: 0;
	    bottom: 0;
	    left: 0;
	    background: -moz-linear-gradient(top, transparent 0%, transparent 18%, rgba(0,0,0,0.8) 99%, rgba(0,0,0,0.8) 100%);
	    background: -webkit-linear-gradient(top, transparent 0%, transparent 18%, rgba(0,0,0,0.8) 99%, rgba(0,0,0,0.8) 100%);
	    background: linear-gradient(to bottom, transparent 0%, transparent 18%, rgba(0,0,0,0.8) 99%, rgba(0,0,0,0.8) 100%);
	    filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#00000000', endColorstr='#cc000000',GradientType=0 );
		}
	}
	.text-overlay {
		position: absolute;
		bottom: 20px;
		left: 20px;
		right: 20px;
		z-index: 10;
		h2 {
			color: $white;
		}
	}
	.text {
		position: relative;
		top: -100px;
		.meta {
			text-transform: uppercase;
			padding-left: 40px;
			color: $white;
			display: block;
			margin-bottom: 20px;
		}
		.text-inner {
			box-shadow: 0 0 20px -5px rgba(0,0,0,.3);
			background: $white;
			padding: 10px;
			margin-right: 30px;			
			position: relative;
			@include media-breakpoint-up(sm) {
				padding: 20px;
			}
			@include media-breakpoint-up(md) {
				padding: 30px 40px;
			}

			&:before {
				position: absolute;
				content: "";
				width: 80px;
				height: 4px;
				margin-top: -4px;
				background: $primary;
				top: 0;
			}
			.heading {
				font-size: 20px;
				margin: 0;
				padding: 0;

			}
		}
	}
}

.block-16 {
	figure {
		position: relative;
		.play-button {
			position: absolute;
			top: 50%;
			left: 50%;
			transform: translate(-50%, -50%);
			font-size: 20px;
			width: 70px;
			height: 70px;
			background: $white;
			display: block;
			border-radius: 50%;
			opacity: 1;
			color: $primary!important;
			&:hover {
				opacity: 1;
			}
			> span {
				position: absolute;
				left: 55%;
				top: 50%;
				transform: translate(-60%, -50%);
			}

		}
	}
}


.block-25 {
	ul {
		&, li {
			padding: 0;
			margin: 0;
		}
		li {
			.date {
				color: rgba($white, .25);
				font-size: $font-size-base - .2rem;
				display: block;
			}
			a {
				.image {
					flex: 0 0 90px;
					img {
						border-radius: 4px;
						max-width: 100%;
						opacity: 1;
						transition: .3s all ease-in-out;
					}
				}
				.text {
					.heading {
						font-size: 18px;
						line-height: 1.5;
						margin: 0;
						padding: 0;
						transition: .3s all ease;
						color: lighten($black, 60%);
					}
				}
				.meta {
					color: $primary;
				}
				&:hover {
					img {
						opacity: .5;
					}
					.text {
						.heading {
							color: $white;
						}
					}
				}
			}
		}
	}
}