.site-blocks-cover {
	background-size: cover;
	background-repeat: no-repeat;
	background-position: top;
	&.overlay {
		position: relative;
		&:before {
			position: absolute;
			content: "";
			left: 0;
			bottom: 0;
			right: 0;
			top: 0;
			background: rgba($black, .4);
		}
	}
	&, .row {
		min-height: 600px;
		height: calc(100vh);
	}

	&.inner-page-cover {
		&, .row {
			min-height: 600px;
			height: calc(30vh);		
		}
	}
	.sub-text {
		font-size: $font-size-base + .1rem;	
		text-transform: uppercase;
		color: rgba($white, .7);
		letter-spacing: .2em;
	}
	h1 {
		font-weight: 900;
		color: $white;
		font-weight: normal;
		letter-spacing: .1em;
		text-transform: uppercase;	
	}
	p {
		color: $white;
		font-size: $font-size-base + .5rem;
		line-height: 1.5;
	}
	.intro-text {
		font-size: 16px;
		line-height: 1.5;
	}

	&.subscribe {
		h2 {
			font-size: 20px;
			letter-spacing: .1em;
			text-transform: uppercase;
			font-weight: 300;
			color: $white;
		}
		p {
			font-size: $font-size-base!important;
			font-weight: 100;
		}
	}

	.property-offer-type {
		letter-spacing: .2em;
		font-size: 12px;
		text-transform: uppercase;
		padding-top: 5px;
		padding-bottom: 5px;
	}
}

.caption-text {
	letter-spacing: .2em;
	font-size: 12px;
	text-transform: uppercase;
	padding-top: 5px;
	padding-bottom: 5px;
}

.site-block-subscribe {
	.btn {
		padding-left: 20px;
		padding-right: 20px;
	}
	.form-control {
		font-weight: 300;
		border-color: $white!important;
		height: 60px;
		color: $white;
		padding-left: 20px;
		padding-right: 20px;
		&::-webkit-input-placeholder { /* Chrome/Opera/Safari */
		  color: rgba($white, .5);
		  font-weight: 200;
		  font-style: italic;
		}
		&::-moz-placeholder { /* Firefox 19+ */
		  color: rgba($white, .5);
		  font-weight: 200;
		  font-style: italic;
		}
		&:-ms-input-placeholder { /* IE 10+ */
		  color: rgba($white, .5);
		  font-weight: 200;
		  font-style: italic;
		}
		&:-moz-placeholder { /* Firefox 18- */
		  color: rgba($white, .5);
		  font-weight: 200;
		  font-style: italic;
		}
	}
}

.social-icon {
	span {
		font-size: 20px;
	}
	&:hover {
		color: $warning!important;
		background: darken($primary, 5%);
	}
}

.property-entry {
	box-shadow: 0 0 10px -2px rgba(0,0,0,.1);
	background: $white;
	.property-body {
		position: relative;
	}
	.property-favorite {
		position: absolute;
		border-radius: 50%;
		top: -60px;
		right: 10px;
		width: 50px;
		height: 50px;
		line-height: 50px;
		background: $white;
		text-align: center;

		span {
			position: absolute;
			top: 50%;
			left: 50%;
			transform: translate(-50%, -50%);
		}
		&:hover, &.active {
			background: $danger;
			color: $white; 
		}
	}
	.offer-type-wrap {
		position: absolute;
		top: 10px;
		left: 10px;
		z-index: 8;
	}
	.property-thumbnail {
		overflow: hidden;
		position: relative;
		display: block;
		.offer-type {
			display: block;
			margin-bottom: 5px;
			// position: absolute;
			padding: 1px 7px;
			color: $white;
			// background: $warning;
			
			text-transform: uppercase;
			letter-spacing: .2em;
			font-size: 9px;
			border-radius: 4px;
		}
		img {
			transition: .3s all ease;
			transform: scale(1.0);
		}
	}
	.property-title {
		font-size: 1.2rem;
		a {
			color: $black;
		}
	}
	.property-location {
		font-size: .9rem;
		.property-icon {
			color: rgba($black, .3);
		}
	}
	.property-specs-number {
		font-size: 1.2rem;
		color: $black;
	}
	.property-specs-wrap {
		list-style: none;
		padding: 0;
		margin: 0;
		li {
			display: inline-block;
			margin-right: 10px;
			margin-bottom: 10px;
		}
	}
	.property-specs {
		display: block;
		text-transform: uppercase;
		font-size: 10px;
		letter-spacing: .1em;
	}
	.property-price {
		font-size: 1.3rem;
	}


	&.horizontal {
		.property-thumbnail {
			flex: 0 0 50%;
		}
		.property-favorite {
			top: auto!important;
			right: auto!important;
			left: -70px!important;
			@include media-breakpoint-down(md) {
				left: auto!important;
				top: -60px!important;
				right: 10px!important;
			}
		}
	}
	&:hover {
		img {
			transform: scale(1.05);
		}
	}
}

.property-specs-wrap {
		list-style: none;
		padding: 0;
		margin: 0;
		li {
			display: inline-block;
			margin-right: 10px;
			margin-bottom: 10px;
		}
	}
	.property-specs {
		display: block;
		text-transform: uppercase;
		font-size: 10px;
		letter-spacing: .1em;
	}
	.property-price {
		font-size: 1.3rem;
	}

.site-section-title {
	h2 {
		text-transform: uppercase;
		color: $black;
		font-weight: 700;
		font-size: 2rem;
		letter-spacing: .1em;
	}
}

.form-search {
	background: #364e68;
	position: relative;
	z-index: 1;
	padding: 3rem 2rem;
	box-shadow: 0 0px 30px 0px rbga(0,0,0,1);
	label {
		text-transform: uppercase;
		font-size: 13px;
		letter-spacing: .1em;
		color: rgba($white, .3);
	}
	.form-control {
		border: none;
	}
	.btn[type="submit"] {
		height: 47px;
	}
}

.select-wrap {
	position: relative;
	.icon {
		display: block;
		position: absolute;
		top: 50%;
		right: 10px;
		line-height: 0;
		font-size: 26px;
		transform: translateY(-50%);
	}
	select {
		appearance: none;
	}
}

.block-13, .slide-one-item {
	position: relative;
	z-index: 1; 
	.owl-nav {
		position: relative;
		position: absolute;
		bottom: 0px;
		left: 50%;
		transform: translateX(-50%);
		.owl-prev, .owl-next {
			position: relative;
			display: inline-block;
			padding: 20px;
			font-size: 30px;
			color: $white;
			&.disabled {
				opacity: .2;
			}
		}
	}
} 

.block-13 {
	.owl-stage-outer {
		padding-top: 30px;
		padding-bottom: 30px;
	}
	.owl-dots {
		text-align: center;
		// border: 1px solid red;
		.owl-dot {
			display: inline-block;
			margin: 5px;
			> span {
				line-height: 0;
				display: inline-block;
				width: 28px;
				height: 4px;
				border: none;
				float: left;
				background: lighten($black, 80%);
				transition: .3s all ease;
			}
			&.active {
				> span {
					background: $primary;
				}
			}
		}
	}
}

.slide-one-item {
	&.home-slider {
		.owl-nav {
			// transition: .3s all ease-in-out;
			// opacity: 0;
			// visibility: hidden;
			position: absolute!important;
			top: 50%!important;
			bottom: auto!important;
			width: 100%;
		}	
		.owl-prev {
			left: 10px!important;
		}
		.owl-next {
			right: 10px!important;
		}
		.owl-prev, .owl-next {
			color: $white;
			position: absolute!important;
			top: 50%;
			padding: 0px;
			height: 50px;
			width: 50px;
			border-radius: 0%;	
			transform: translateY(-50%);
			background: rgba($black, .2);
			transition: .3s all ease-in-out;
			
			line-height: 0;
			text-align: center;
			font-size: 25px;
			@include media-breakpoint-up(md) {
				font-size: 25px;
			}
			> span {
				position: absolute;
				line-height: 0;
				top: 50%;
				left: 50%;
				transform: translate(-50%, -50%);
			}
			
			&:hover, &:focus {
				background: rgba($black, 1);
			}
		}

		&:hover, &:focus, &:active {
			.owl-nav {
				opacity: 10;
				visibility: visible;
			}
		}
	}	
}

.service {
	display: block;
	.icon {
		font-size: 60px;
		color: $primary;
	}
	.service-heading {
		color: $black;
		font-size: 1.2rem;
		margin-bottom: 1rem;
	}
	p {
		color: rgba($black, .6);
	}
	.read-more {
		text-transform: uppercase;
		font-size: 12px;
		letter-spacing: .2em;
	}
}

.view-options {
	.icon-view {
		font-size: 20px;
		color: lighten($black, 50%);
		&.active {
			color: $black;
		}
	}
	a {
		font-size: 14px;
		color: lighten($black, 50%);
		&:hover {
			color: lighten($black, 0%);
		}
		&.active {
			color: $black;
		}
	}
}

.site-pagination {
	a {
		display: inline-block;
		width: 50px;
		border-radius: 50%;
		height: 50px;
		line-height: 50px;
		background: $white;
		color: lighten($black, 20%);
		border: 1px solid lighten($black, 90%);

		&:hover {
			box-shadow: 0 4px 10px -1px rgba(0,0,0,.05);
			border: 1px solid lighten($black, 80%);
		}
		&.active {
			border: 1px solid transparent;
			background: $success;
			color: $white;
			&:hover {
				border: 1px solid transparent;
				box-shadow: none;
			}
		}
	}
	span {
		display: inline-block;
		width: 20px;
	}
}

.unit-8 {
	.accordion-item {
		.heading {
			font-size: 1.2rem;
			font-weight: 400;
			padding: 10px 0;
			> a {
				padding-left: 35px;
				position: relative;
				color: $black;
				&:before {

					width: 20px;
					height: 20px;
					line-height: 18px;
					border: 1px solid #ccc;
					text-align: center;
					font-size: 18px;
					top: .1em;
					left: 0;
				}
				&[aria-expanded="true"] {
					&:before {
						font-family: 'icomoon';
						position: absolute;
						content: "\e316";
						transition: .3s all ease;
						background: $primary;
						color: $white;
						border: 1px solid $primary;
					}
				}
				&[aria-expanded="false"] {
					&:before {
						content: "\e313";
						color: #ccc;	
						font-family: 'icomoon';
						position: absolute;
				
						transition: .3s all ease;
					}
				}
				
			}
		}
		.body-text {
			padding: 5px 0;
			padding-left: 30px;
		}
	}
}

.widget {
	padding: 40px;
	margin-bottom: 30px;
	.widget-title {
		font-size: 14px;
		font-weight: bold;
		color: $black;
		text-transform: uppercase;
		letter-spacing: .1em;
	}
}
.form-contact-agent {
	.form-control {
		height: 37px;
	}
}
.property-body {
	padding: 40px;
}

.gal-item {
	img {
		transition: .3s all ease;
		opacity: 1;
	}
	&:hover {
		
		img {
			cursor: zoom-in;
			opacity: .5;
		}
	}
}