.site-blocks-cover {
	background-size: cover;
	background-repeat: no-repeat;
	background-position: top;
	&.overlay {
		position: relative;
		&:before {
			position: absolute;
			content: "";
			left: 0;
			bottom: 0;
			right: 0;
			top: 0;
			background: rgba($black, .4);
		}
	}
	&, .row {
		min-height: 600px;
		height: calc(100vh);
	}

	&.inner-page-cover {
		&, .row {
			min-height: 600px;
			height: calc(30vh);		
		}
	}
	.sub-text {
		font-size: $font-size-base + .1rem;	
		text-transform: uppercase;
		color: rgba($white, .7);
		letter-spacing: .2em;
	}
	h1 {
		font-weight: 900;
		color: $white;
		font-size: 4rem;
		font-weight: normal;
		letter-spacing: .1em;
		text-transform: uppercase;	
	}
	p {
		color: $white;
		font-size: $font-size-base + .5rem;
		line-height: 1.5;
	}
	.intro-text {
		font-size: 16px;
		line-height: 1.5;
	}

	&.subscribe {
		h2 {
			font-size: 20px;
			letter-spacing: .1em;
			text-transform: uppercase;
			font-weight: 300;
			color: $white;
		}
		p {
			font-size: $font-size-base!important;
			font-weight: 100;
		}
	}
}

.site-block-subscribe {
	.btn {
		padding-left: 20px;
		padding-right: 20px;
	}
	.form-control {
		font-weight: 300;
		// border-color: $white!important;
		height: 60px;
		color: $black;
		padding-left: 20px;
		padding-right: 20px;
		// &::-webkit-input-placeholder { /* Chrome/Opera/Safari */
		//   color: rgba($white, .5);
		//   font-weight: 200;
		//   font-style: italic;
		// }
		// &::-moz-placeholder { /* Firefox 19+ */
		//   color: rgba($white, .5);
		//   font-weight: 200;
		//   font-style: italic;
		// }
		// &:-ms-input-placeholder { /* IE 10+ */
		//   color: rgba($white, .5);
		//   font-weight: 200;
		//   font-style: italic;
		// }
		// &:-moz-placeholder { /* Firefox 18- */
		//   color: rgba($white, .5);
		//   font-weight: 200;
		//   font-style: italic;
		// }
	}
}

.site-heading {
	
	font-weight: 300;
	text-transform: uppercase;
	font-size: $font-size-base + 1rem;
	@include media-breakpoint-up(md) {
		font-size: $font-size-base + 2rem;	
	}
	strong {
		font-weight: 900;
	}
}

.site-block-1 {
	padding-top: 50px;
	@include media-breakpoint-up(lg) {
		padding-top: 0;
		position: absolute;
		width: 100%;
		transform: translateY(-100%);
	}
}

.site-block-appointment {
	background: #ece8d9!important;
	form {
		box-shadow: 0 5px 20px -2px rgba(0,0,0,.1);
	}
}
.text-white-opacity-5 {
	color: rgba($white, .5);
}
.text-black-opacity-5 {
	color: rgba($black, .5);
}

.site-block-feature {
	background: rgba($black, .5);
	position: relative;
	
	.icon {
		font-size: 50px;

	}
	h3 {
		font-size: 15px;
		letter-spacing: .1em;
		text-transform: uppercase;
		color: $white;
	}
	p {
		color: rgba($white, .4);
		font-size: $font-size-base;
		&:last-child {
			margin-bottom: 0;
		}
	}
}
.site-block-feature-2 {
	.icon {
		font-size: 50px;
		position: relative;
		line-height: 1;
	}
	h3 {
		font-size: $font-size-base + .5rem;
	}
}

.site-block-3 {
	.row-items {
		height: calc(50% - 15px);
		margin-bottom: 30px;
		&.last {
			height: calc(50% - 15px);
			margin-bottom: 0;
		}
	}
	.feature {
		transition: .3s all ease-in-out;
		height: 100%;

		h3 {
			color: $black;
			font-size: $font-size-base + .4rem;
		}
		&:hover, &:active, &:focus, &.active {
			box-shadow: 0 5px 20px -2px rgba(0,0,0,.1);
		}
	}
}

.site-block-half {

	.image, .text {
		width: 100%;
		@include media-breakpoint-up(lg) {
			width: 50%;	
		}
	}
	.image {
		@include media-breakpoint-down(md) {
			margin-bottom: 50px;
		}
	}
	.text {
		padding-left: 15px;
		padding-right: 15px;
		@include media-breakpoint-up(lg) {
			padding: 4rem;	
		}
		@include media-breakpoint-up(xl) {
			padding: 8rem 4rem;	
		}
	}
	.bg-image {
		background-position: center center;
		@include media-breakpoint-down(md) {
			height: 400px;
		}
	}

	&.site-block-video {
		.image {
			position: relative;
			.play-button {
				position: absolute;
				top: 50%;
				left: 50%;
				transform: translate(-50%, -50%);
				font-size: 20px;
				width: 70px;
				height: 70px;
				background: $white;
				display: block;
				border-radius: 50%;
				opacity: 1;
				color: $primary!important;
				&:hover {
					opacity: 1;
				}
				> span {
					position: absolute;
					left: 55%;
					top: 50%;
					transform: translate(-60%, -50%);
				}

			}
		}
	}
}

.site-block-testimony {
	img {
		max-width: 140px;
		border-radius: 50%;
	}
	p {
		font-size: $font-size-base + .2rem;
	}
	&.active {
		background: $white;
		box-shadow: 0 5px 20px -2px rgba(0,0,0,.1);
	}
}



.post-entry {
	position: relative;
	overflow: hidden;
	border: 1px solid lighten($black, 90% );
	&, .text {
		border-radius: 4px;	
		border-top: none!important;
	} 
	.date {
		color: darken(#ccc, 15%);
		font-weight: normal;
		letter-spacing: .1em;
	}

	.image {
		overflow: hidden;
		position: relative;
		img {
			transition: .3s all ease;
			transform: scale(1.0);
		}
	}
	&:hover, &:active, &:focus {
		.image {
			img {
				transform: scale(1.2);
			}
		}
	}
}

.block-13, .slide-one-item {
	position: relative;
	z-index: 1; 
	.owl-nav {
		position: relative;
		position: absolute;
		bottom: 0px;
		left: 50%;
		transform: translateX(-50%);
		.owl-prev, .owl-next {
			position: relative;
			display: inline-block;
			padding: 20px;
			font-size: 30px;
			color: $white;
			&.disabled {
				opacity: .2;
			}
		}
	}
} 

.block-13 {
	.owl-stage-outer {
		padding-top: 30px;
		padding-bottom: 30px;
	}
	.owl-dots {
		text-align: center;
		// border: 1px solid red;
		.owl-dot {
			display: inline-block;
			margin: 5px;
			> span {
				line-height: 0;
				display: inline-block;
				width: 28px;
				height: 4px;
				border: none;
				float: left;
				background: lighten($black, 80%);
				transition: .3s all ease;
			}
			&.active {
				> span {
					background: $primary;
				}
			}
		}
	}
}

.slide-one-item {
	&.home-slider {
		.owl-nav {
			// transition: .3s all ease-in-out;
			// opacity: 0;
			// visibility: hidden;
			position: absolute!important;
			top: 50%!important;
			bottom: auto!important;
			width: 100%;
		}	
		.owl-prev {
			left: 10px!important;
		}
		.owl-next {
			right: 10px!important;
		}
		.owl-prev, .owl-next {
			color: $white;
			position: absolute!important;
			top: 50%;
			padding: 0px;
			height: 50px;
			width: 50px;
			border-radius: 0%;	
			transform: translateY(-50%);
			background: rgba($black, .2);
			transition: .3s all ease-in-out;
			
			line-height: 0;
			text-align: center;
			font-size: 25px;
			@include media-breakpoint-up(md) {
				font-size: 25px;
			}
			> span {
				position: absolute;
				line-height: 0;
				top: 50%;
				left: 50%;
				transform: translate(-50%, -50%);
			}
			
			&:hover, &:focus {
				background: rgba($black, 1);
			}
		}

		&:hover, &:focus, &:active {
			.owl-nav {
				opacity: 10;
				visibility: visible;
			}
		}
	}	
}


.block-12 {
	position: relative;
	figure {
		position: relative;
		&:before {
			content: '';
	    position: absolute;
	    top: 0;
	    right: 0;
	    bottom: 0;
	    left: 0;
	    background: -moz-linear-gradient(top, transparent 0%, transparent 18%, rgba(0,0,0,0.8) 99%, rgba(0,0,0,0.8) 100%);
	    background: -webkit-linear-gradient(top, transparent 0%, transparent 18%, rgba(0,0,0,0.8) 99%, rgba(0,0,0,0.8) 100%);
	    background: linear-gradient(to bottom, transparent 0%, transparent 18%, rgba(0,0,0,0.8) 99%, rgba(0,0,0,0.8) 100%);
	    filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#00000000', endColorstr='#cc000000',GradientType=0 );
		}
	}
	.text-overlay {
		position: absolute;
		bottom: 20px;
		left: 20px;
		right: 20px;
		z-index: 10;
		h2 {
			color: $white;
		}
	}
	.text {
		position: relative;
		top: -100px;
		.meta {
			text-transform: uppercase;
			padding-left: 40px;
			color: $white;
			display: block;
			margin-bottom: 20px;
		}
		.text-inner {
			box-shadow: 0 0 20px -5px rgba(0,0,0,.3);
			background: $white;
			padding: 10px;
			margin-right: 30px;			
			position: relative;
			@include media-breakpoint-up(sm) {
				padding: 20px;
			}
			@include media-breakpoint-up(md) {
				padding: 30px 40px;
			}

			&:before {
				position: absolute;
				content: "";
				width: 80px;
				height: 4px;
				margin-top: -4px;
				background: $primary;
				top: 0;
			}
			.heading {
				font-size: 20px;
				margin: 0;
				padding: 0;

			}
		}
	}
}

.block-16 {
	figure {
		position: relative;
		.play-button {
			position: absolute;
			top: 50%;
			left: 50%;
			transform: translate(-50%, -50%);
			font-size: 20px;
			width: 70px;
			height: 70px;
			background: $white;
			display: block;
			border-radius: 50%;
			opacity: 1;
			color: $primary!important;
			&:hover {
				opacity: 1;
			}
			> span {
				position: absolute;
				left: 55%;
				top: 50%;
				transform: translate(-60%, -50%);
			}

		}
	}
}


.block-25 {
	ul {
		&, li {
			padding: 0;
			margin: 0;
		}
		li {
			.date {
				color: rgba($white, .25);
				font-size: $font-size-base - .2rem;
				display: block;
			}
			a {
				.image {
					flex: 0 0 90px;
					img {
						border-radius: 4px;
						max-width: 100%;
						opacity: 1;
						transition: .3s all ease-in-out;
					}
				}
				.text {
					.heading {
						font-size: $font-size-base - .1rem;
						line-height: 1.5;
						margin: 0;
						padding: 0;
						transition: .3s all ease;
						color: lighten($black, 60%);
					}
				}
				.meta {
					color: $primary;
				}
				&:hover {
					img {
						opacity: .5;
					}
					.text {
						.heading {
							color: $white;
						}
					}
				}
			}
		}
	}
}

#date-countdown {
	.countdown-block {
		color: rgba($white, .4);
	}
	.label {
		font-size: 40px;
		color: $white;
	}
}

.next-match {
	.image {
		width: 50px;
		border-radius: 50%;
	}
}

.player {
	position: relative;
	img {
		max-width: 100px;
		border-radius: 50%;
		margin-bottom: 20px;
	}
	.team-number {
		position: absolute;
		width: 30px;
		height: 30px;
		background: $primary;
		border-radius: 50%;
		color: $white;
		> span {
			position: absolute;
			transform: translate(-50%, -50%);
			left: 50%;
			top: 50%;
		}
	}
	h2 {
		font-size: 20px;
		letter-spacing: .2em;
		text-transform: uppercase;
	}
	.position {
		font-size: 14px;
		color: lighten($black, 70%);
		text-transform: uppercase;
	}
}

.site-block-27 {
	ul {
		&, li {
			padding: 0;
			margin: 0;
		}
		li {
			display: inline-block;
			margin-bottom: 4px;
			a,span {
				text-align: center;
				display: inline-block;
				width: 40px;
				height: 40px;
				line-height: 40px;
				border-radius: 50%;
				border: 1px solid #ccc;
			}
			&.active {
				a, span {
					background: $primary;
					color: $white;
					border: 1px solid transparent;
				}
			}
		}
	}
}

.block-47 {
	.block-47-image {
		flex: 0 0 70px;
		display: block;
		img {
			border: 5px solid $white;
			border-radius: 50%;
			box-shadow: 0 2px 30px -2px rgba(0,0,0,.1);
		}
	}
	.block-47-quote {
		
		padding: 30px;
		
		font-weight: 300;
		background: $white;
		border-radius: 7px;
		position: relative;
		box-shadow: 0 2px 30px -2px rgba(0,0,0,.1);
		@include media-breakpoint-up(md) {
			margin-left: 40px;
			font-size: 1.2rem;
		}

		&:before {
			content: "";
			border: 1px solid red;
			z-index: 2;
			position: absolute;

			left: -15px;

			border-width: 0 20px 20px 0;
			border-style: solid;
			border-color: transparent #fff transparent transparent;
		}

		.block-47-quote-author {
			font-size: 14px;
			color: lighten($black, 40%);
		}
	}
}

.site-block-check {
	padding: 0;
	margin: 0 0 30px 0;
	li {
		padding: 0;
		margin: 0;
	}

	li {
		display: block;
		padding-left: 30px;
		position: relative;
		margin-bottom: 10px;
		&:before {
			position: absolute;
			color: $success;
			left: 0;
			top: -.3rem;
			font-family: 'icomoon';
			font-size: 1.1rem;
			content: "\e5ca";
		}

	}
}

.half-sm {
	.text {
		
		&, h2, small {
			transition: .3s all ease-in-out;
		}
		a {
			small {
				border-bottom: 2px solid transparent;
			}
		}
	}
	&:hover, &:focus {
		.text {
			background: $primary!important;
			color: $white;
			h2 {
				color: $white!important;
			}
			a {
				small {
					color: $white!important;
					border-bottom: 2px solid $white;
				}
			}
		}
	}
}

.block-37 {

	border-radius: 4px;
	display: block;
	overflow: hidden;
	width: 100%; 
	height: 200px;
  // height: 300px;
	.image {
		height: 100%;
		// width: 100%;
	 //  height: 100%;
	  background-color: black; /* fallback color */
	  background-position: center;
	  background-size: cover;
	  position: relative;
		transition: .8s all ease;
	  &:before {
			content: "";
		  visibility: hidden;
		  opacity: 0;
		  height: 100%;
		  width: 100%;
		  position: absolute;
		  transition: .3s all ease;
		  top: 0;
		  left: 0;
		  background-color: $primary;
		}

		.block-37-overlay {
			z-index: 3;
			position: absolute;
			top: 50%;
			left: 50%;
			opacity: 0;
			visibility: hidden;
			transition: .3s all ease;
			transform: translate(-50%, -50%);
			margin-top: 10px;
			.icon {
				font-size: 30px;
				color: $white;
			}
		}

	}
	&:hover, &:focus {
		.block-37-overlay {
			opacity: 1;
			visibility: visible;
			margin-top: 0px;
		}
		.image {
			transform: scale(1.2);
			&:before {
				opacity: .7;
				visibility: visible;
			}
		}
	}
}

.site-navbar-top {
	.block-unit {
		.icon {
			line-height: 0;
			@include media-breakpoint-down(md) {
				span {
					font-size: 20px!important;
				}
			}
		}
		.muted {
			color: $gray-200;
		}
	}
}

// search domain
.popular-domain-extension {
	.border-right {
		border-right: 1px solid rgba($white, .2)!important;
	}
}
.extenionlist {
	border: 1px solid red;
	appearance: none;
}
.search-domain {
	.search-input {
		background: none;
		border: 1px solid rgba(255,255,255,.7);
		color: $white;
		&::placeholder {
			color: $white;
		}
	}
	.btn {
		background: $primary;
	}
	.select-wrap {
		position: relative;
		select {
			padding-right: 30px;
		}
		.arrow-down {
			position: absolute;
			right: 10px;
			top: 50%;
			font-size: 20px;
			transform: translateY(-50%);
		}
	}
}


.unit-2 {
	box-shadow: 0 5px 20px -5px rgba(0,0,0,.2);
	.icon {
		font-size: 4rem;
	}
}
.unit-3 {
	padding: 30px;
	border: 2px solid lighten($black, 90%);
	position: relative;
	transition: .3s all ease;
	&:before {
		content: "";
		position: absolute;
		left: 0;
		right: 0;
		bottom: 0;
		top: 0;
		transform: scale(1.07);
		opacity: 0;
		visibility: hidden;
		transition: .3s all ease;
		background: $primary;
	}
	.unit-3-heading, .unit-3-body {
		position: relative;
		z-index: 2;
	}
	.unit-3-icon-wrap {
		position: relative;
		height: 68px;
		width: 59px;
		flex: 0 0 59px;
	}
	.unit-3-svg {
	  position: absolute;
	  stroke: $primary;
	  transition: .3s all ease;
	}
	.unit-3-icon {
		position: absolute;
		top: 50%;
		left: 50%;
		font-size: 2rem;
		transform: translate(-50%, -50%);
		transition: .3s all ease;
	}
	p {
		color: lighten($black, 70%);
	}

	&:hover, &:focus {
		border: 2px solid transparent;
		h2 {
			color: $white;
		}
		.unit-3-body {
			&, p {
				color: $white;
			}
		}
		.unit-3-svg {
		  position: absolute;
		  stroke: $white;
		}
		.unit-3-icon {
			color: $white;
		}
		&:before {
			opacity: 1;
			visibility: visible;
			transform: scale(1.0);
		}
	}
}


//### .block-4
.block-4 {
	.nonloop-block-4 {
		.owl-stage {
			padding-bottom: 2em;
		}
		// .owl-item {
		// 	box-shadow: 0 7px 20px -5px rgba(0,0,0,.2);	
		// }
		.owl-nav {
			z-index: 2;
			position: absolute;
			width: 100%;
			bottom: -2px;
			.owl-prev, .owl-next {
				opacity: .2;
				transition: .3s all ease;
				&:hover {
					opacity: 1;
				}
				&.disabled {
					display: none;
				}
				position: absolute;
				span {
					font-size: 30px;
				}
			}
			.owl-prev {
				left: 50px;

			}
			.owl-next {
				right: 50px;
			}
		}
		.owl-dots {
			bottom: -40px;
			position: absolute;
			width: 100%;
			text-align: center;
			.owl-dot {
				display: inline-block;
				width: 8px;
				height: 8px;
				background: #ccc;
				border-radius: 50%;
				margin-right: 10px;
				margin-bottom: 10px;
				transition: .3s all ease;
				&.active {
					background: $primary;
				}
			}
		}
	}
}
.block-38 {
	text-align: center;
	.block-38-header {
		.block-38-heading {
			font-size: 18px;
			color: $black;
			margin: 0;
			font-weight: 300;
		}
		.block-38-subheading {
			color: lighten($black, 70%);
			margin: 0 0 20px 0;
			text-transform: uppercase;
		}
		img {
			width: 90px;
			margin: 0 auto;
			border-radius: 50%;
			margin-bottom: 20px;
		}
	}
	.block-38-body {
		font-size: 1.1rem;
	}
}

.unit-4 {
	padding: 0;
	margin: 0;
	list-style: none;
	li {
		display: inline-block; 
		margin-right: 30px;
		&:last-child {
			margin-right: 0;
		}
	}
}

.unit-5 {
	padding-top: 50px;
	padding-bottom: 50px;
	background-size: cover;
	background-position: center center;
	&.overlay {
		position: relative;
		&:before {
			position: absolute;
			content: "";
			left: 0;
			right: 0;
			bottom: 0;
			top: 0;
			z-index: 1;
			background: rgba(0,0,0,.5);
		}
	}
	> .container {
		z-index: 2;
		position: relative;
	}
	h2 {
		color: $white;
		font-size: 3rem;
	}
}

.unit-6 {
	color: $white;
	.sep {
		color: rgba($white, .2);
		margin: 0 10px;
	}
}


// Pricing
.unit-7 {
	max-width: 100%;
	margin-left: auto;
	margin-right: auto;
	text-align: center;
	background: #ffffff;
	border: 3px solid #e8e8e8;
	.pricing-table__item-header {
		position: relative;
		z-index: 1;
		display: inline-block;
		top: -12px;
		margin-bottom: -12px;
		text-align: center;
		color: #ffffff;
		padding: 9px 40px;
		min-width: 200px;
		width: auto;
		max-width: 90%;
		margin-left: auto;
		margin-right: auto;
		&:before, &:after {
			content: '';
			position: absolute;
			top: 0;
			width: 0;
			height: 0;
			border-style: solid;
			border-width: 0 6px 12px 6px;
			border-color: transparent transparent #2c3640 transparent;
			z-index: 2;
		}
		&:before {
			left: -6px;
		}
		&:after {
			right: -6px;
		}
	}
	.pricing-table__item-header-bg {
		position: absolute;
		overflow: hidden;
		z-index: 1;
		top: 0;
		bottom: 0;
		left: -1px;
		right: -1px;
		transform-origin: top;
		transform: skew(-27deg);
	}
	.pricing-table__item-header-bg-inner {
		position: absolute;
		top: 0;
		bottom: 0;
		left: 0;
		right: 0;
		transform: skew(27deg);
		transform-origin: top;
		&:before {
			content: '';
			position: absolute;
			top: 0;
			right: 0;
			bottom: 0;
			left: 0;
			transform: skew(27deg);
			transform-origin: top;
			background: #3e4955;
		}
	}
	.pricing-table__item-main {
		padding: 30px;
	}
	.pricing-table__item-title {
		position: relative;
		z-index: 2;
		font-weight: 700;
		letter-spacing: .075em;
		text-transform: uppercase;
	}
	ul {
		li {
			margin-bottom: 10px;
		}
	}
	.text-mark {
		color: $black;
		font-weight: bold;
	}
	&.featured-pricing {
		.pricing-table__item-header {
			&:before, &:after {
				border-color: transparent transparent darken($primary, 10%) transparent;
			}
		}
		.pricing-table__item-header-bg-inner {
			&:before {
				background: $primary;
			}
		}
	}
}

.unit-8 {
	.accordion-item {
		.heading {
			font-size: 1.2rem;
			font-weight: 400;
			padding: 10px 0;
			> a {
				padding-left: 35px;
				position: relative;
				color: $black;
				&:before {

					width: 20px;
					height: 20px;
					line-height: 18px;
					border: 1px solid #ccc;
					text-align: center;
					font-size: 18px;
					top: .1em;
					left: 0;
				}
				&[aria-expanded="true"] {
					&:before {
						font-family: 'icomoon';
						position: absolute;
						content: "\e316";
						transition: .3s all ease;
						background: $primary;
						color: $white;
						border: 1px solid $primary;
					}
				}
				&[aria-expanded="false"] {
					&:before {
						content: "\e313";
						color: #ccc;	
						font-family: 'icomoon';
						position: absolute;
				
						transition: .3s all ease;
					}
				}
				
			}
		}
		.body-text {
			padding: 5px 0;
			padding-left: 30px;
		}
	}
}

.padded-multi-line-primary {
  display: inline;
  background: $primary;
  box-shadow: 10px 0 0 $primary, 0px 0 0 $primary;
}
.padded-multi-line-black {
  display: inline;
  background: $black;
  box-shadow: 10px 0 0 $black, 0px 0 0 $black;
}

.unit-9 {
	background-size: cover;
	background-position: center center;
	background-repeat: none;
	height: 300px;
	position: relative;
	display: block;
	overflow: hidden;
	.image {
		background-size: cover;
		background-position: center center;
		transition: .3s all ease-in-out;
		height: 300px;
		transition: .3s all ease;
		transform: scale(1.05);
	} 
	&.no-height {
		height: auto;
		.image {
			height: auto;
			position: absolute;
			top: 0;
			left: 0;
			right: 0;
			bottom: 0;
		}
	}
	.unit-9-content {
		transition: .3s all ease-in-out;
		position: absolute;
		// top: 50%;
		// transform: translateY(-50%);
		bottom: 0;
	}
	h2 {
		padding-left: 10px;
		padding-top: 5px;
		padding-bottom: 5px;
		color: $white;
		font-size: 20px;
		margin-bottom: 0;
		@extend .padded-multi-line-primary;
	}
	span {
		background: $black;
		display: block;
		color: $white;
		padding-left: 10px;
		padding-top: 4px;
		padding-bottom: 4px;
		font-size: 11px;
		letter-spacing: .15em;
		text-transform: uppercase;
		@extend .padded-multi-line-black;
	}
	&:hover {
		.image {
			transform: scale(1.0);
		}
	}
}

.site-section-heading {
	h2 {
		font-size: 2rem;
		letter-spacing: .2em;
		text-transform: uppercase;
	}
	&.w-border {
		h2 {
			position: relative;
			padding-bottom: 20px;
			display: inline-block;
			&:after {
				position: absolute;
				content: "";
				width: 70px;
				left: 0;
				bottom: 0;
				height: 2px;
				background: $primary;
			}
		}
		&.text-center {
		 h2 {
		 	&:after {
		 		left: 50%;
		 		transform: translateX(-50%);
		 	}
		 }
		}
	}
}

.backgroundimg {
	background-size: cover;
	background-position: center center;
	background-repeat: no-repeat;
	position: relative;
}
.site-block-retro {
	.col1, .col2 {
		width: 48%;
		@include media-breakpoint-down(sm) {
			width: 100%;
		}
	}
	.col1 {
		@extend .backgroundimg;
		@include media-breakpoint-down(sm) {
			height: 300px;
			margin-bottom: 8%;
		}
	}
	.col2 {
		> a {
			display: block;
			@extend .backgroundimg;
			height: 300px;
			&:first-child {
				margin-bottom: 8%;
			}
		}
	}
}

.pill {
	border-radius: 30px;
}

.team-member {
	position: relative;
	float: left;
	width: 100%;
	overflow: hidden;
	img {
		transition: .3s all ease;
		transform: scale(1.0);
	}
	&:before {
		position: absolute;
		content: "";
		top: 0; left: 0; right: 0; bottom: 0;
		background: rgba($primary, .8);
		z-index: 2;
		height: 100%;
		width: 100%;
		opacity: 0;
		visibility: hidden;
		transition: .3s all ease;
	}
	.text {
		top: 50%;
		text-align: center;
		position: absolute;
		// top: 20px;
		// bottom: 20px;
		// left: 20px;
		// right: 20px;
		padding: 20px;
		transform: translateY(-30%);
		transition: .5s all ease;
		opacity: 0;
		visibility: hidden;
		// color: $white;
	}
	&:hover, &:focus, &:active {
		&:before {
			opacity: 1;
			visibility: visible;
		}
		img {
			transform: scale(1.1);
		}
		.text {
			transform: translateY(-50%);
			transition-delay: .2s;
			opacity: 1;
			visibility: visible;
			z-index: 4;
		}
	}
}

.social-icon {
	span {
		font-size: 20px;
	}
	&:hover {
		color: $warning!important;
		background: darken($primary, 5%);
	}
}

.podcast-entry {
	box-shadow: 0 5px 40px -10px rgba(0,0,0,.1);
	.sep {
		margin-left: 5px;
		margin-right: 5px;
		color: #ccc;
	}
	.image {
		
		background-size: cover;
		background-position: center center;
		background-repeat: no-repeat;
		height: 300px;
		@include media-breakpoint-up(md) {
			width: 300px;
			height: auto;
		}
	}
	.text {
		width: 100%;
		padding: 40px;
		@include media-breakpoint-up(md) {
			width: calc(100% - 300px);	
		}
	}
}
.mejs__container {
	width: 100%!important;
}

form {
	.form-control {
		background: none;
		// color: $white!important;
		&:active, &:focus {
			background: none;
		}
	}
}

figure {
	img {
		margin-bottom: 10px;
	}
	figcaption {
		font-size: .8rem;
		font-style: italic;
	}
}

.comment-form-wrap {
	clear: both;
}

.comment-list {
	padding: 0;
	margin: 0;
	.children {
		padding: 50px 0 0 40px;
		margin: 0;
		float: left;
		width: 100%;
	}
	li {
		padding: 0;
		margin: 0 0 30px 0;
		float: left;
		width: 100%;
		clear: both;
		list-style: none;
		.vcard {
			width: 80px;
			float: left;
			img {
				width: 50px;
				border-radius: 50%;
			}
		}
		.comment-body {
			float: right;
			width: calc(100% - 80px);
			h3 {
				font-size: 20px;
				color: $white;
			}
			.meta {
				text-transform: uppercase;
				font-size: 13px;
				letter-spacing: .1em;
				color: #ccc;
			}
			.reply {
				padding: 5px 10px;
				background: $primary;
				color: $white;
				text-transform: uppercase;
				font-size: 12px;
				&:hover {
					color: $white;
					background: $primary;
				}
			}
		}
	}
}



.featured-property-half {
	position: relative;
	background: $white;
	margin-top: -100px;
	box-shadow: 0 0 20px -5px rgba($black, .1);
	div {
		width: 50%;
	}
	.image {
		background-size: cover;
		background-position: center center;
		background-repeat: no-repeat;
	}
	.text {
		padding: 100px;
		ul {
			padding: 0;
			margin: 0;
			list-style: none;
			color: #777;
			strong {
				color: $black;
				font-weight: bold;
			}
			li {

				margin-bottom: 10px;
			}
		}

	}
}
